@@ -1,10 +1,10 @@
 /*
     Drumstick MIDI realtime input-output
-    Copyright (C) 2009-2016 Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2009-2020 Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -12,9 +12,8 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef MIDIINPUT_H
@@ -26,22 +25,24 @@
 #include <QtPlugin>
 #include <QSettings>
 
+#include "macros.h"
 #include "rtmidioutput.h"
 
 /**
  * @file rtmidiinput.h
  * Realtime MIDI input interface
- * @addtogroup RT
- * @{
  */
 
-namespace drumstick {
-namespace rt {
+namespace drumstick { namespace rt {
 
     /**
+     * @addtogroup RT
+     * @{
+     *
+     * @class MIDIInput
      * @brief MIDI IN interface
      */
-    class MIDIInput : public QObject
+    class DRUMSTICK_EXPORT MIDIInput : public QObject
     {
         Q_OBJECT
 
@@ -50,11 +51,11 @@ namespace rt {
          * @brief MIDIInput constructor
          * @param parent
          */
-        explicit MIDIInput(QObject *parent = 0) : QObject(parent) {}
+        explicit MIDIInput(QObject *parent = nullptr) : QObject(parent) {}
         /**
          * @brief ~MIDIInput destructor
          */
-        virtual ~MIDIInput() {}
+        virtual ~MIDIInput() = default;
         /**
          * @brief initialize
          * @param settings
@@ -77,9 +78,10 @@ namespace rt {
         virtual void setPublicName(QString name) = 0;
         /**
          * @brief connections
+         * @param advanced whether the advanced connections are included or not
          * @return list of available MIDI ports
          */
-        virtual QStringList connections(bool advanced = false) = 0;
+        virtual QList<MIDIConnection> connections(bool advanced = false) = 0;
         /**
          * @brief setExcludedConnections
          * @param conns
@@ -87,9 +89,9 @@ namespace rt {
         virtual void setExcludedConnections(QStringList conns) = 0;
         /**
          * @brief open the MIDI port by name
-         * @param name
+         * @param conn Connection to open
          */
-        virtual void open(QString name) = 0;
+        virtual void open(const MIDIConnection& conn) = 0;
         /**
          * @brief close the MIDI port
          */
@@ -98,7 +100,7 @@ namespace rt {
          * @brief currentConnection
          * @return name of the current connection if it is opened
          */
-        virtual QString currentConnection() = 0;
+        virtual MIDIConnection currentConnection() = 0;
         /**
          * @brief setMIDIThruDevice
          * @param device
@@ -111,7 +113,7 @@ namespace rt {
         virtual void enableMIDIThru(bool enable) = 0;
         /**
          * @brief isEnabledMIDIThru
-         * @return
+         * @return MIDI Thru is enabled
          */
         virtual bool isEnabledMIDIThru() = 0;
 
@@ -187,10 +189,11 @@ namespace rt {
          */
         void midiSystemRealtime(const int status);
     };
-}}
-
-Q_DECLARE_INTERFACE(drumstick::rt::MIDIInput, "net.sourceforge.drumstick.rt.MIDIInput/1.0")
 
 /** @} */
 
+}} // namespace drumstick::rt
+
+Q_DECLARE_INTERFACE(drumstick::rt::MIDIInput, "net.sourceforge.drumstick.rt.MIDIInput/2.0")
+
 #endif // MIDIINPUT_H
